@@ -1,8 +1,8 @@
 import os
 
-import autolens.plot as aplt
 import pytest
-from autoconf import conf
+
+import autolens.plot as aplt
 
 directory = os.path.dirname(os.path.realpath(__file__))
 
@@ -12,17 +12,9 @@ def make_fit_imaging_plotter_setup():
     return "{}/files/plots/fit/".format(os.path.dirname(os.path.realpath(__file__)))
 
 
-@pytest.fixture(autouse=True)
-def set_config_path():
-    conf.instance = conf.Config(
-        os.path.join(directory, "files/plotter"), os.path.join(directory, "output")
-    )
-
-
 def test__fit_quantities_are_output(
     masked_imaging_fit_x2_plane_7x7, include_all, plot_path, plot_patch
 ):
-
     aplt.FitImaging.image(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
@@ -83,7 +75,6 @@ def test__fit_quantities_are_output(
 def test__fit_sub_plot(
     masked_imaging_fit_x2_plane_7x7, include_all, plot_path, plot_patch
 ):
-
     aplt.FitImaging.subplot_fit_imaging(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
@@ -100,7 +91,6 @@ def test__subtracted_image_of_plane_is_output(
     plot_path,
     plot_patch,
 ):
-
     aplt.FitImaging.subtracted_image_of_plane(
         fit=masked_imaging_fit_x1_plane_7x7,
         plane_index=0,
@@ -136,7 +126,6 @@ def test__model_image_of_plane_is_output(
     plot_path,
     plot_patch,
 ):
-
     aplt.FitImaging.model_image_of_plane(
         fit=masked_imaging_fit_x1_plane_7x7,
         plane_index=0,
@@ -168,7 +157,6 @@ def test__model_image_of_plane_is_output(
 def test_subplot_fit_imaging_is_output(
     masked_imaging_fit_x2_plane_7x7, include_all, plot_path, plot_patch
 ):
-
     aplt.FitImaging.subplot_fit_imaging(
         fit=masked_imaging_fit_x2_plane_7x7,
         include=include_all,
@@ -185,7 +173,6 @@ def test__subplot_of_plane(
     plot_path,
     plot_patch,
 ):
-
     aplt.FitImaging.subplot_of_plane(
         fit=masked_imaging_fit_x1_plane_7x7,
         plane_index=0,
@@ -238,7 +225,6 @@ def test__fit_individuals__source_and_lens__dependent_on_input(
     plot_path,
     plot_patch,
 ):
-
     aplt.FitImaging.individuals(
         fit=masked_imaging_fit_x1_plane_7x7,
         plot_image=True,
